@@ -3,9 +3,12 @@
 #define _NGXE_H_INCLUDED_
 
 #include <ngxe_ngx.h>
+#include <ngxe_debug.h>
 #include <ngxe_timer.h>
 #include <ngxe_xs.h>
+#include <ngxe_bufs.h>
 #include <ngxe_connection.h>
+#include <ngxe_http.h>
 
 #define NGXE_START  0x01
 
